@@ -2,6 +2,10 @@
 //
 // (C) Copyright Seb Wills 2005
 
+#ifndef WIN32
+#include <unistd.h>
+#endif
+
 #include "../Common/Common.h"
 
 #include "SocketInputBase.h"
